@@ -67,11 +67,11 @@ class Dispatch(object):
 		self.connection = SMTP()
 		self.connection.set_debuglevel(debug)
 
-	@property
 	def connected(self):
 		"""Return the current SMTP connection status."""
 		
 		return getattr(self.connection, 'sock', None) is not None
+	connected = property(connected)
 
 	def connect(self):
 		"""Connect to the SMTP server if not already connected.
